@@ -66,7 +66,7 @@ class CatalogQuery():
         self.dbclient = dbclient
         if dbclient is None:
             self.dbclient = pymongo.MongoClient()
-        self.logger.debug("using mongo client at %s:%d"%(self.dbclient.address))
+        self.logger.debug(f"using mongo client at {self.dbclient.address}")
         
         # find database and collection
         if not cat_name in self.dbclient.list_database_names():
@@ -124,9 +124,9 @@ class CatalogQuery():
             self.ra_key = ra_key or "_ra"
             self.dec_key = dec_key or "_dec"
         if not self.has_2dsphere:
-            if ra_key is None:
+            if self.ra_key is None:
                 raise ValueError("ra_key not found in metadata or provided as kwarg")
-            if dec_key is None:
+            if self.dec_key is None:
                 raise ValueError("dec_key not found in metadata or provided as kwarg")
 
 
